@@ -104,7 +104,7 @@ static pthread_mutex_t error_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 Atom X11DRV_Atoms[NB_XATOMS - FIRST_XATOM];
 
-static const char * const atom_names[NB_XATOMS - FIRST_XATOM] =
+const char * const X11DRV_atom_names[NB_XATOMS - FIRST_XATOM] =
 {
     "CLIPBOARD",
     "COMPOUND_TEXT",
@@ -122,6 +122,8 @@ static const char * const atom_names[NB_XATOMS - FIRST_XATOM] =
     "RAW_CAP_HEIGHT",
     "WM_PROTOCOLS",
     "WM_DELETE_WINDOW",
+    "WM_HINTS",
+    "WM_NORMAL_HINTS",
     "WM_STATE",
     "WM_TAKE_FOCUS",
     "DndProtocol",
@@ -738,7 +740,7 @@ static NTSTATUS x11drv_init( void *arg )
     init_visuals( display, DefaultScreen( display ));
     screen_bpp = pixmap_formats[default_visual.depth]->bits_per_pixel;
 
-    XInternAtoms( display, (char **)atom_names, NB_XATOMS - FIRST_XATOM, False, X11DRV_Atoms );
+    XInternAtoms( display, (char **)X11DRV_atom_names, NB_XATOMS - FIRST_XATOM, False, X11DRV_Atoms );
 
     init_win_context();
 
